.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.mailutil.mail
--------------------------

.. automodule:: reahl.mailutil.mail


MailMessage
"""""""""""

.. autoclass:: MailMessage
   :members:

Mailer
""""""

.. autoclass:: Mailer
   :members:
